About Plone
===========

Plone is a user friendly Content Management System running on top of Python,
Zope and the CMF.

It benefits from all features of Zope/CMF such as: RDBMS integration,
Python extensions, Object Oriented Database, Web configurable workflow,
pluggable membership and authentication, Undos, Form validation, amongst many
many other features. Available protocols: FTP, XMLRPC, HTTP and WEBDAV
Turn it into a distributed application system by installing ZEO.

Plone shares some of the qualities of Livelink, Interwoven and Documentum. It
aims to be *the* open source out-of-the-box publishing system.

What is Plone?
--------------

Plone is a ready-to-run content management system that is built on the powerful
and free Zope application server. Plone is easy to set up, extremely flexible,
and provides you with a system for managing web content that is ideal for
project groups, communities, web sites, extranets and intranets.

- *Plone is easy to install.* You can install Plone with a a click and run
  installer, and have a content management system running on your computer in
  just a few minutes.

- *Plone is easy to use.* The Plone Team includes usability experts who have
  made Plone easy and attractive for content managers to add, update, and
  maintain content.

- *Plone is international.* The Plone interface has more than 35 translations,
  and tools exist for managing multilingual content.

- *Plone is standard.* Plone carefully follows standards for usability and
  accessibility. Plone pages are compliant with US Section 508, and the W3C's
  AAA rating for accessibility.

- *Plone is Open Source.* Plone is licensed under the GNU General Public
  License, the same license used by Linux. This gives you the right to use
  Plone without a license fee, and to improve upon the product.

- *Plone is supported.* There are over three hundred developers in the Plone
  Development Team around the world, and a multitude of companies that
  specialize in Plone development and support.

- *Plone is extensible.* There is a multitude of add-on products for Plone to
  add new features and content types. In addition, Plone can be scripted using
  web standard solutions and Open Source languages.

- *Plone is technology neutral.* Plone can interoperate with most relational
  database systems, open source and commercial, and runs on a vast array of
  platforms, including Linux, Windows, Mac OS X, Solaris and BSD.

Technical overview
------------------

Plone is a content management framework that works hand-in-hand and sits on top
of Zope, a widely-used Open Source web application server and development
system. To use Plone, you don't need to learn anything about Zope; to develop
new Plone content types, a small amount of Zope knowledge is helpful, and it is
covered in the `documentation`_.

Zope itself is written in Python, an easy-to-learn, widely-used and supported
Open Source programming language. Python can be used to add new features to
Plone, and used to understand or make changes to the way that Zope and Plone
work.

By default, Plone stores its contents in Zope's built in transactional object
database, the ZODB. There are products and techniques, however, to share
information with other sources, such as relational databases, LDAP, filesystem
files, etc.

Plone runs on Windows, Linux, BSD, Mac OS X, and many other platforms;
double-click installers are available for Windows and Mac OS X, and RPM
packages are available for Linux. For full information, see the
`documentation`_.

.. _documentation: http://docs.plone.org
